@@ -26,6 +26,7 @@ import com.github.tomakehurst.wiremock.client.WireMock;
 import com.github.tomakehurst.wiremock.common.Slf4jNotifier;
 import org.eclipse.che.api.factory.server.scm.PersonalAccessTokenManager;
 import org.eclipse.che.api.factory.server.urlfactory.DevfileFilenamesProvider;
+import org.eclipse.che.security.oauth.OAuthAPI;
 import org.mockito.Mock;
 import org.mockito.testng.MockitoTestNGListener;
 import org.testng.annotations.BeforeClass;
@@ -38,6 +39,7 @@ import org.testng.annotations.Test;
 public class BitbucketServerURLParserTest {
 
   @Mock private DevfileFilenamesProvider devfileFilenamesProvider;
+  @Mock private OAuthAPI oAuthAPI;
 
   /** Instance of component that will be tested. */
   private BitbucketServerURLParser bitbucketURLParser;
@@ -59,6 +61,7 @@ public class BitbucketServerURLParserTest {
         new BitbucketServerURLParser(
             "https://bitbucket.2mcl.com,https://bbkt.com",
             devfileFilenamesProvider,
+            oAuthAPI,
             mock(PersonalAccessTokenManager.class));
   }
 
@@ -70,9 +73,11 @@ public class BitbucketServerURLParserTest {
 
   /** Compare parsing */
   @Test(dataProvider = "parsing")
-  public void checkParsing(String url, String project, String repository, String branch) {
+  public void checkParsing(
+      String url, String user, String project, String repository, String branch) {
     BitbucketServerUrl bitbucketServerUrl = bitbucketURLParser.parse(url);
 
+    assertEquals(bitbucketServerUrl.getUser(), user);
     assertEquals(bitbucketServerUrl.getProject(), project);
     assertEquals(bitbucketServerUrl.getRepository(), repository);
     assertEquals(bitbucketServerUrl.getBranch(), branch);
@@ -91,7 +96,7 @@ public class BitbucketServerURLParserTest {
     // given
     bitbucketURLParser =
         new BitbucketServerURLParser(
-            null, devfileFilenamesProvider, mock(PersonalAccessTokenManager.class));
+            null, devfileFilenamesProvider, oAuthAPI, mock(PersonalAccessTokenManager.class));
     String url = wireMockServer.url("/users/user/repos/repo");
     stubFor(
         get(urlEqualTo("/rest/access-tokens/1.0/users/0")).willReturn(aResponse().withStatus(401)));
@@ -120,8 +125,12 @@ public class BitbucketServerURLParserTest {
   @DataProvider(name = "UrlsProvider")
   public Object[][] urls() {
     return new Object[][] {
+      {"https://bitbucket.2mcl.com/scm/~user/repo.git"},
       {"https://bitbucket.2mcl.com/scm/project/test1.git"},
       {"https://bitbucket.2mcl.com/projects/project/repos/test1/browse?at=refs%2Fheads%2Fbranch"},
+      {"https://bitbucket.2mcl.com/projects/project/repos/test1/browse"},
+      {"https://bitbucket.2mcl.com/users/user/repos/repo"},
+      {"https://bitbucket.2mcl.com/users/user/repos/repo/"},
       {"https://bbkt.com/scm/project/test1.git"},
     };
   }
@@ -129,19 +138,22 @@ public class BitbucketServerURLParserTest {
   @DataProvider(name = "parsing")
   public Object[][] expectedParsing() {
     return new Object[][] {
-      {"https://bitbucket.2mcl.com/scm/project/test1.git", "project", "test1", null},
+      {"https://bitbucket.2mcl.com/scm/project/test1.git", null, "project", "test1", null},
       {
         "https://bitbucket.2mcl.com/projects/project/repos/test1/browse?at=refs%2Fheads%2Fbranch",
+        null,
         "project",
         "test1",
         "refs%2Fheads%2Fbranch"
       },
       {
         "https://bbkt.com/projects/project/repos/test1/browse?at=refs%2Fheads%2Fbranch",
+        null,
         "project",
         "test1",
         "refs%2Fheads%2Fbranch"
-      }
+      },
+      {"https://bbkt.com/users/user/repos/repo/", "user", null, "repo", null}
     };
   }
 }
