@@ -19,13 +19,12 @@ import java.net.MalformedURLException;
 import org.eclipse.che.api.factory.server.bitbucket.server.BitbucketServerApiClient;
 import org.eclipse.che.api.factory.server.bitbucket.server.BitbucketUser;
 import org.eclipse.che.api.factory.server.scm.GitUserData;
-import org.eclipse.che.api.factory.server.scm.exception.ScmBadRequestException;
-import org.eclipse.che.api.factory.server.scm.exception.ScmCommunicationException;
-import org.eclipse.che.api.factory.server.scm.exception.ScmItemNotFoundException;
-import org.eclipse.che.api.factory.server.scm.exception.ScmUnauthorizedException;
+import org.eclipse.che.api.factory.server.scm.PersonalAccessTokenManager;
+import org.eclipse.che.api.factory.server.scm.exception.*;
 import org.eclipse.che.commons.env.EnvironmentContext;
 import org.eclipse.che.commons.subject.Subject;
 import org.eclipse.che.commons.subject.SubjectImpl;
+import org.eclipse.che.security.oauth.OAuthAPI;
 import org.mockito.Mock;
 import org.mockito.testng.MockitoTestNGListener;
 import org.testng.annotations.BeforeMethod;
@@ -37,6 +36,8 @@ public class BitbucketServerUserDataFetcherTest {
   String someBitbucketURL = "https://some.bitbucketserver.com";
   Subject subject;
   @Mock BitbucketServerApiClient bitbucketServerApiClient;
+  @Mock PersonalAccessTokenManager personalAccessTokenManager;
+  @Mock OAuthAPI oAuthAPI;
   BitbucketUser bitbucketUser;
   BitbucketServerUserDataFetcher fetcher;
 
@@ -45,7 +46,13 @@ public class BitbucketServerUserDataFetcherTest {
     subject = new SubjectImpl("another_user", "user987", "token111", false);
     bitbucketUser =
         new BitbucketUser("User", "user", 32423523, "NORMAL", true, "user", "user@users.com");
-    fetcher = new BitbucketServerUserDataFetcher(bitbucketServerApiClient, someBitbucketURL);
+    fetcher =
+        new BitbucketServerUserDataFetcher(
+            "api.local",
+            someBitbucketURL,
+            bitbucketServerApiClient,
+            oAuthAPI,
+            personalAccessTokenManager);
     EnvironmentContext context = new EnvironmentContext();
     context.setSubject(subject);
     EnvironmentContext.setCurrent(context);
@@ -54,14 +61,14 @@ public class BitbucketServerUserDataFetcherTest {
   @Test
   public void shouldBeAbleToFetchPersonalAccessToken()
       throws ScmUnauthorizedException, ScmCommunicationException, ScmItemNotFoundException,
-          ScmBadRequestException {
+          ScmBadRequestException, ScmConfigurationPersistenceException {
     // given
     when(bitbucketServerApiClient.isConnected(eq(someBitbucketURL))).thenReturn(true);
     when(bitbucketServerApiClient.getUser(eq(subject))).thenReturn(bitbucketUser);
     // when
     GitUserData gitUserData = fetcher.fetchGitUserData();
     // then
-    assertEquals(gitUserData.getScmUsername(), "user");
+    assertEquals(gitUserData.getScmUsername(), "User");
     assertEquals(gitUserData.getScmUserEmail(), "user@users.com");
   }
 }
